Description Usage Arguments Details Value See Also
gbt.save is an interface for storing a agtboost model.
1 |
gbt_model |
Model object or pointer to object of class |
file |
Valid file-path |
The model-storage function for agtboost.
Saves a GTB model as a txt file. Might be retrieved using gbt.load
Txt file that can be loaded using gbt.load.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.